#delimit ;

/* This do file replicates the results in the paper "Is Private Campaign Finance a Good Thing? Estimates of the Potential Informational Benefits",
  by Andrea Prat, Riccardo Puglisi and James M. Snyder, Jr. */


/* Stata version used to obtain and replicate those results: Stata 10.1 */


/*
local directory "C:\Documents and Settings\Puglisi\Documenti\lavoro\ricerca\campaign_finance\qjps\data\REPLICATION"; 
*/


local directory "C:\Users\Riccardo\Documents\lavoro\ricerca\campaign_finance\qjps\FINAL_VERSION";



clear;

set memory 100m;
set matsize 5000;
capture
cd "`directory'";

capture log close;
log using replicate_results, replace text;







use pps_campaign_finance;

/****************************************************************************************************************/

/* Table 1, summary statistics. We do it for both the House and the Senate, through a loop on senate_d */

foreach zz of numlist 0 1 {;
sum   leg_effectiveness  total_contrib tot_contrib_below_2000 tot_contrib_above_2000 
	own_funds party_funds contrib_from_organizations contrib_from_individuals 
	woman_d democ_party_d black_d age_at_election lawyer_d terms_in_office maj_party_d 
	top_posts_held  
	     if senate_d ==`zz';

centile leg_effectiveness  total_contrib tot_contrib_below_2000 tot_contrib_above_2000 
	own_funds party_funds contrib_from_organizations contrib_from_individuals 
	woman_d democ_party_d black_d age_at_election lawyer_d terms_in_office maj_party_d 
	top_posts_held  
	     if senate_d ==`zz';


};


/*****************************************************************************************************************/



/* Table 2: explaining legislator effectiveness, uninformed voters */

/* regressions for the Lower House */

reg leg_effectiveness woman_d democ_party_d if senate_d ==0, cluster(candidate_id); /* column [1] */
reg leg_effectiveness total_contrib woman_d democ_party_d if senate_d ==0, cluster(candidate_id); /* column [2] */
reg leg_effectiveness tot_contrib_below_2000 tot_contrib_above_2000 woman_d democ_party_d 
			if senate_d ==0, cluster(candidate_id); /* column [3] */
reg leg_effectiveness own_funds party_funds contrib_from_organizations contrib_from_individuals  
		woman_d democ_party_d if senate_d ==0, cluster(candidate_id); /* column [4] */




/* regressions for the Senate */

reg leg_effectiveness woman_d democ_party_d if senate_d ==1, cluster(candidate_id); /* column [5] */
reg leg_effectiveness total_contrib woman_d democ_party_d if senate_d ==1, cluster(candidate_id); /* column [6] */
reg leg_effectiveness tot_contrib_below_2000 tot_contrib_above_2000 woman_d democ_party_d 
			if senate_d ==1, cluster(candidate_id); /* column [7] */
reg leg_effectiveness own_funds party_funds contrib_from_organizations contrib_from_individuals  
		woman_d democ_party_d if senate_d ==1, cluster(candidate_id); /* column [8] */




/*****************************************************************************************************************/



/* Table 3: explaining legislator effectiveness, informed voters */

/* regressions for the Lower House */

reg leg_effectiveness woman_d democ_party_d black_d age_at_election lawyer_d terms_in_office maj_party_d top_posts_held  
			if senate_d ==0, cluster(candidate_id); /* column [1] */

reg leg_effectiveness total_contrib woman_d democ_party_d black_d age_at_election lawyer_d terms_in_office maj_party_d top_posts_held  
			if senate_d ==0, cluster(candidate_id); /* column [2] */


reg leg_effectiveness tot_contrib_below_2000 tot_contrib_above_2000 woman_d democ_party_d black_d age_at_election lawyer_d 
			terms_in_office maj_party_d top_posts_held   
			if senate_d ==0, cluster(candidate_id); /* column [3] */


reg leg_effectiveness own_funds party_funds contrib_from_organizations contrib_from_individuals  
		woman_d democ_party_d black_d age_at_election lawyer_d 
		terms_in_office maj_party_d top_posts_held  if senate_d ==0, cluster(candidate_id); /* column [4] */




/* regressions for the Senate */

reg leg_effectiveness woman_d democ_party_d black_d age_at_election lawyer_d terms_in_office top_posts_held  
			if senate_d ==1, cluster(candidate_id); /* column [5] */


reg leg_effectiveness total_contrib woman_d democ_party_d black_d age_at_election lawyer_d terms_in_office top_posts_held  
			if senate_d ==1, cluster(candidate_id); /* column [6] */


reg leg_effectiveness tot_contrib_below_2000 tot_contrib_above_2000 woman_d democ_party_d black_d age_at_election 
			lawyer_d terms_in_office top_posts_held   
			if senate_d ==1, cluster(candidate_id); /* column [7] */


reg leg_effectiveness own_funds party_funds contrib_from_organizations contrib_from_individuals  
		woman_d democ_party_d black_d age_at_election lawyer_d terms_in_office top_posts_held  
			if senate_d ==1, cluster(candidate_id); /* column [8] */

/****************************************************************************************************************/


/* Table 4: overall R squared */


/* NOTE: the relevant R squared and p-values on F tests will be first copied in newly created variables. 
	Then those values will be organised in a matrix, whose format corresponds to Tables 4.A and 4.B */


/* Lower House */




capture drop f_tests_cf_house; /* this variable will be filled with the p-values of the relevant f tests to be performed, 
						regarding campaign finance scenarios */
capture drop f_tests_dv_house;  /* this variable will be filled with the p-values of the relevant f tests to be performed, 
						regarding the difference between uninformed and informed voters */
gen f_tests_cf_house = .;
gen f_tests_dv_house = .;


capture drop r2_house; /* this variable will contain R squared of the regressions being run */

gen r2_house=0;




/* observable controls */

reg leg_effectiveness  democ woman_d  democ_party_d if senate_d==0, cluster(candidate_id);

replace r2_house=e(r2)*100 in 1;




reg leg_effectiveness  total_contrib
           democ_party_d woman_d if senate_d==0, cluster(candidate_id);

replace r2_house=e(r2)*100  in 2;



test total_contrib=0;

replace f_tests_cf_house = r(p) in 1;
local p1= r(p);




reg leg_effectiveness   tot_contrib_below_2000  tot_contrib_above_2000 
           	woman_d democ_party_d  if senate_d==0, cluster(candidate_id);

replace r2_house=e(r2)*100 in 3;



test tot_contrib_below_2000 = tot_contrib_above_2000;

replace f_tests_cf_house = r(p) in 2;
local p1= r(p);





reg leg_effectiveness  own_funds party_funds contrib_from_organizations contrib_from_individuals  
           woman_d democ_party_d  if senate_d==0, cluster(candidate_id);

replace r2_house=e(r2)*100 in 4;



test own_funds  = party_funds = contrib_from_organizations = contrib_from_individuals ;

replace f_tests_cf_house = r(p) in 3;
local p1= r(p);









/* informed voters part */




reg leg_effectiveness  woman_d democ_party_d  black_d age_at_election lawyer_d terms_in_office maj_party_d  top_posts_held  
			if senate_d==0, cluster(candidate_id);

replace r2_house=e(r2)*100 in 5;


test age_at_election = lawyer_d = terms_in_office = black_d= maj_party_d  = top_posts_held  = 0;
replace f_tests_dv_house = r(p) in 1;








reg leg_effectiveness  total_contrib  
           democ woman_d black_d age_at_election lawyer_d terms_in_office maj_party_d top_posts_held    
			 if senate_d==0, cluster(candidate_id);

replace r2_house=e(r2)*100 in 6;



test age_at_election = lawyer_d = terms_in_office = black_d= maj_party_d  = top_posts_held  = 0;
replace f_tests_dv_house = r(p) in 2;

test total_contrib=0;

replace f_tests_cf_house = r(p) in 4;
local p1= r(p);







reg leg_effectiveness  tot_contrib_below_2000  tot_contrib_above_2000    
           democ_party_d woman_d black_d age_at_election lawyer_d terms_in_office maj_party_d top_posts_held   
		 if senate_d==0, cluster(candidate_id);


replace r2_house=e(r2)*100 in 7;



test age_at_election = lawyer_d = terms_in_office = black_d= maj_party_d  = top_posts_held  = 0;
replace f_tests_dv_house = r(p) in 3;

test tot_contrib_below_2000 = tot_contrib_above_2000  ;
replace f_tests_cf_house = r(p) in 5;
local p1= r(p);






reg leg_effectiveness own_funds party_funds contrib_from_organizations contrib_from_individuals   
		woman_d democ_party_d  black_d age_at_election
           lawyer_d terms_in_office maj_party_d top_posts_held   
            if senate_d==0, cluster(candidate_id);

replace r2_house=e(r2)*100 in 8;


test age_at_election = lawyer_d = terms_in_office = black_d= maj_party_d  = top_posts_held  = 0;

replace f_tests_dv_house = r(p) in 4;

test own_funds  = party_funds = contrib_from_organizations = contrib_from_individuals ;

replace f_tests_cf_house = r(p) in 6;
local p1= r(p);










capture matrix drop f_tests_house;

matrix define f_tests_house = (r2_house[1],f_tests_cf_house[1],r2_house[2],f_tests_cf_house[2],r2_house[3],f_tests_cf_house[3],r2_house[4]
					\f_tests_dv_house[1],.,f_tests_dv_house[2],.,f_tests_dv_house[3],.,f_tests_dv_house[4]
					\r2_house[5],f_tests_cf_house[4],r2_house[6],f_tests_cf_house[5],r2_house[7],f_tests_cf_house[6],r2_house[8]);




matrix list f_tests_house;


/************************************************************/


/* Senate */




capture drop f_tests_cf_senate; /* this variable will be filled with the p-values of the relevant f tests to be performed, 
						regarding campaign finance scenarios */
capture drop f_tests_dv_senate;  /* this variable will be filled with the p-values of the relevant f tests to be performed, 
						regarding the difference between uninformed and informed voters */
gen f_tests_cf_senate = .;
gen f_tests_dv_senate = .;


capture drop r2_senate; /* this variable will contain R squared of the regressions being run */

gen r2_senate=0;




/* observable controls */

reg leg_effectiveness  democ woman_d  democ_party_d if senate_d==1, cluster(candidate_id);

replace r2_senate=e(r2)*100 in 1;




reg leg_effectiveness  total_contrib
           democ_party_d woman_d if senate_d==1, cluster(candidate_id);

replace r2_senate=e(r2)*100  in 2;



test total_contrib=0;

replace f_tests_cf_senate = r(p) in 1;
local p1= r(p);




reg leg_effectiveness   tot_contrib_below_2000  tot_contrib_above_2000 
           	woman_d democ_party_d  if senate_d==1, cluster(candidate_id);

replace r2_senate=e(r2)*100 in 3;



test tot_contrib_below_2000 = tot_contrib_above_2000;

replace f_tests_cf_senate = r(p) in 2;
local p1= r(p);





reg leg_effectiveness  own_funds party_funds contrib_from_organizations contrib_from_individuals  
           woman_d democ_party_d  if senate_d==1, cluster(candidate_id);

replace r2_senate=e(r2)*100 in 4;



test own_funds  = party_funds = contrib_from_organizations = contrib_from_individuals ;

replace f_tests_cf_senate = r(p) in 3;
local p1= r(p);









/* informed voters part */




reg leg_effectiveness  woman_d democ_party_d  black_d age_at_election lawyer_d terms_in_office  top_posts_held  
			if senate_d==1, cluster(candidate_id);

replace r2_senate=e(r2)*100 in 5;


test age_at_election = lawyer_d = terms_in_office = black_d= top_posts_held  = 0;
replace f_tests_dv_senate = r(p) in 1;








reg leg_effectiveness  total_contrib  
           democ woman_d black_d age_at_election lawyer_d terms_in_office top_posts_held    
			 if senate_d==1, cluster(candidate_id);

replace r2_senate=e(r2)*100 in 6;



test age_at_election = lawyer_d = terms_in_office = black_d   = top_posts_held  = 0;
replace f_tests_dv_senate = r(p) in 2;

test total_contrib=0;

replace f_tests_cf_senate = r(p) in 4;
local p1= r(p);







reg leg_effectiveness  tot_contrib_below_2000  tot_contrib_above_2000    
           democ_party_d woman_d black_d age_at_election lawyer_d terms_in_office top_posts_held   
		 if senate_d==1, cluster(candidate_id);


replace r2_senate=e(r2)*100 in 7;



test age_at_election = lawyer_d = terms_in_office = black_d  = top_posts_held  = 0;
replace f_tests_dv_senate = r(p) in 3;

test tot_contrib_below_2000 = tot_contrib_above_2000  ;
replace f_tests_cf_senate = r(p) in 5;
local p1= r(p);






reg leg_effectiveness own_funds party_funds contrib_from_organizations contrib_from_individuals   
		woman_d democ_party_d  black_d age_at_election
           lawyer_d terms_in_office  top_posts_held   
            if senate_d==1, cluster(candidate_id);

replace r2_senate=e(r2)*100 in 8;


test age_at_election = lawyer_d = terms_in_office = black_d  = top_posts_held  = 0;

replace f_tests_dv_senate = r(p) in 4;

test own_funds  = party_funds = contrib_from_organizations = contrib_from_individuals ;

replace f_tests_cf_senate = r(p) in 6;
local p1= r(p);










capture matrix drop f_tests_senate;

matrix define f_tests_senate = (r2_senate[1],f_tests_cf_senate[1],r2_senate[2],f_tests_cf_senate[2],r2_senate[3],f_tests_cf_senate[3],r2_senate[4]
					\f_tests_dv_senate[1],.,f_tests_dv_senate[2],.,f_tests_dv_senate[3],.,f_tests_dv_senate[4]
					\r2_senate[5],f_tests_cf_senate[4],r2_senate[6],f_tests_cf_senate[5],r2_senate[7],f_tests_cf_senate[6],r2_senate[8]);





matrix list f_tests_senate;







/*****************************************************************************************************************/


/* Table 5, robustness checks, House */

/* first part: controlling for challenger spending */

reg leg_effectiveness total_contrib woman_d democ_party_d perseat_challenger_contrib if senate_d ==0, cluster(candidate_id); /* column [1] */

reg leg_effectiveness tot_contrib_below_2000 tot_contrib_above_2000 woman_d democ_party_d perseat_challenger_contrib 
			if senate_d ==0, cluster(candidate_id); /* column [2] */

reg leg_effectiveness own_funds party_funds contrib_from_organizations contrib_from_individuals  
		woman_d democ_party_d perseat_challenger_contrib if senate_d ==0, cluster(candidate_id); /* column [3] */



reg leg_effectiveness total_contrib woman_d democ_party_d black_d age_at_election lawyer_d terms_in_office maj_party_d 
			top_posts_held  perseat_challenger_contrib
			if senate_d ==0, cluster(candidate_id); /* column [4] */


reg leg_effectiveness tot_contrib_below_2000 tot_contrib_above_2000 woman_d democ_party_d black_d 
			age_at_election lawyer_d terms_in_office maj_party_d 
			top_posts_held  perseat_challenger_contrib 
			if senate_d ==0, cluster(candidate_id); /* column [5] */


reg leg_effectiveness own_funds party_funds contrib_from_organizations contrib_from_individuals  
		woman_d democ_party_d black_d age_at_election lawyer_d terms_in_office maj_party_d 
		top_posts_held  perseat_challenger_contrib
		if senate_d ==0, cluster(candidate_id); /* column [6] */


/* second part: including candidate fixed effects */



xi: reg leg_effectiveness total_contrib democ_party_d i.candidate_id if senate_d ==0, cluster(candidate_id); /* column [7] */

xi: reg leg_effectiveness tot_contrib_below_2000 tot_contrib_above_2000 democ_party_d i.candidate_id  
			if senate_d ==0, cluster(candidate_id); /* column [8] */

xi: reg leg_effectiveness own_funds party_funds contrib_from_organizations contrib_from_individuals  
		democ_party_d i.candidate_id if senate_d ==0, cluster(candidate_id); /* column [9] */



xi: reg leg_effectiveness total_contrib democ_party_d age_at_election lawyer_d terms_in_office maj_party_d 
			top_posts_held  i.candidate_id 
			if senate_d ==0, cluster(candidate_id); /* column [10] */


xi: reg leg_effectiveness tot_contrib_below_2000 tot_contrib_above_2000 democ_party_d
			age_at_election lawyer_d terms_in_office maj_party_d top_posts_held   i.candidate_id
			if senate_d ==0, cluster(candidate_id); /* column [11] */


xi: reg leg_effectiveness own_funds party_funds contrib_from_organizations contrib_from_individuals  
		democ_party_d age_at_election lawyer_d terms_in_office maj_party_d top_posts_held   i.candidate_id
		if senate_d ==0, cluster(candidate_id); /* column [12] */




/******************************************************************************************************************/

/* Tables in the online appendix 														*/

/******************************************************************************************************************/




/* Table A1: challenger spending, uninformed voters */

/* regressions for the House */

reg leg_effectiveness total_contrib woman_d democ_party_d perseat_challenger_contrib if senate_d ==0, cluster(candidate_id); /* column [1] */

reg leg_effectiveness tot_contrib_below_2000 tot_contrib_above_2000 woman_d democ_party_d perseat_challenger_contrib 
			if senate_d ==0, cluster(candidate_id); /* column [2] */

reg leg_effectiveness own_funds party_funds contrib_from_organizations contrib_from_individuals  
		woman_d democ_party_d perseat_challenger_contrib if senate_d ==0, cluster(candidate_id); /* column [3] */




/* regressions for the Senate */

reg leg_effectiveness total_contrib woman_d democ_party_d perseat_challenger_contrib if senate_d ==1, cluster(candidate_id); /* column [4] */

reg leg_effectiveness tot_contrib_below_2000 tot_contrib_above_2000 woman_d democ_party_d perseat_challenger_contrib 
			if senate_d ==1, cluster(candidate_id); /* column [5] */

reg leg_effectiveness own_funds party_funds contrib_from_organizations contrib_from_individuals  
		woman_d democ_party_d perseat_challenger_contrib if senate_d ==1, cluster(candidate_id); /* column [6] */




/******************************************************************************************************************/



/* Table A2: challenger spending, informed voters */

/* regressions for the House */


reg leg_effectiveness total_contrib woman_d democ_party_d black_d age_at_election lawyer_d terms_in_office maj_party_d 
			top_posts_held  perseat_challenger_contrib
			if senate_d ==0, cluster(candidate_id); /* column [1] */


reg leg_effectiveness tot_contrib_below_2000 tot_contrib_above_2000 woman_d democ_party_d black_d 
			age_at_election lawyer_d terms_in_office maj_party_d  top_posts_held  perseat_challenger_contrib 
			if senate_d ==0, cluster(candidate_id); /* column [2] */


reg leg_effectiveness own_funds party_funds contrib_from_organizations contrib_from_individuals  
		woman_d democ_party_d black_d age_at_election lawyer_d terms_in_office maj_party_d 
		top_posts_held  perseat_challenger_contrib
		if senate_d ==0, cluster(candidate_id); /* column [3] */



/* regressions for the Senate */


reg leg_effectiveness total_contrib woman_d democ_party_d black_d age_at_election lawyer_d terms_in_office 
			top_posts_held  perseat_challenger_contrib
			if senate_d ==1, cluster(candidate_id); /* column [4] */


reg leg_effectiveness tot_contrib_below_2000 tot_contrib_above_2000 woman_d democ_party_d black_d 
			age_at_election lawyer_d terms_in_office top_posts_held  perseat_challenger_contrib 
			if senate_d ==1, cluster(candidate_id); /* column [5] */


reg leg_effectiveness own_funds party_funds contrib_from_organizations contrib_from_individuals  
		woman_d democ_party_d black_d age_at_election lawyer_d terms_in_office top_posts_held  perseat_challenger_contrib
		if senate_d ==1, cluster(candidate_id); /* column [6] */



/******************************************************************************************************************/


/* Table A3: candidate fixed effects, uninformed voters */


/* regressions for the House */

xi: reg leg_effectiveness democ_party_d i.candidate_id if senate_d ==0, cluster(candidate_id); /* column [1] */

xi: reg leg_effectiveness total_contrib democ_party_d i.candidate_id if senate_d ==0, cluster(candidate_id); /* column [2] */

xi: reg leg_effectiveness tot_contrib_below_2000 tot_contrib_above_2000 democ_party_d i.candidate_id  
			if senate_d ==0, cluster(candidate_id); /* column [3] */

xi: reg leg_effectiveness own_funds party_funds contrib_from_organizations contrib_from_individuals  
		democ_party_d i.candidate_id if senate_d ==0, cluster(candidate_id); /* column [4] */



/* regressions for the Senate */

xi: reg leg_effectiveness   i.candidate_id if senate_d ==1, cluster(candidate_id); /* column [5] */

xi: reg leg_effectiveness total_contrib  i.candidate_id if senate_d ==1, cluster(candidate_id); /* column [6] */

xi: reg leg_effectiveness tot_contrib_below_2000 tot_contrib_above_2000  i.candidate_id  
			if senate_d ==1, cluster(candidate_id); /* column [7] */

xi: reg leg_effectiveness own_funds party_funds contrib_from_organizations contrib_from_individuals  
		i.candidate_id if senate_d ==1, cluster(candidate_id); /* column [8] */


/******************************************************************************************************************/


/* Table A4: candidate fixed effects, informed voters */


/* regressions for the House */

xi: reg leg_effectiveness  democ_party_d age_at_election lawyer_d terms_in_office 
			maj_party_d top_posts_held  i.candidate_id 
			if senate_d ==0, cluster(candidate_id); /* column [1] */


xi: reg leg_effectiveness total_contrib democ_party_d age_at_election lawyer_d terms_in_office 
			maj_party_d top_posts_held  i.candidate_id 
			if senate_d ==0, cluster(candidate_id); /* column [2] */


xi: reg leg_effectiveness tot_contrib_below_2000 tot_contrib_above_2000 democ_party_d
			age_at_election lawyer_d terms_in_office maj_party_d top_posts_held   i.candidate_id
			if senate_d ==0, cluster(candidate_id); /* column [3] */


xi: reg leg_effectiveness own_funds party_funds contrib_from_organizations contrib_from_individuals  
		democ_party_d age_at_election lawyer_d terms_in_office maj_party_d top_posts_held   i.candidate_id
		if senate_d ==0, cluster(candidate_id); /* column [4] */





/* regressions for the Senate */


xi: reg leg_effectiveness  age_at_election lawyer_d terms_in_office top_posts_held  i.candidate_id 
			if senate_d ==1, cluster(candidate_id); /* column [5] */




xi: reg leg_effectiveness total_contrib  age_at_election lawyer_d terms_in_office top_posts_held  i.candidate_id 
			if senate_d ==1, cluster(candidate_id); /* column [6] */


xi: reg leg_effectiveness tot_contrib_below_2000 tot_contrib_above_2000 
			age_at_election lawyer_d terms_in_office top_posts_held   i.candidate_id
			if senate_d ==1, cluster(candidate_id); /* column [7] */


xi: reg leg_effectiveness own_funds party_funds contrib_from_organizations contrib_from_individuals  
		 age_at_election lawyer_d terms_in_office top_posts_held   i.candidate_id
		if senate_d ==1, cluster(candidate_id); /* column [8] */





/******************************************************************************************************************/

/* Table A5: different thresholds between large and small contributions, uninformed voters */


/* regressions for the House */

reg leg_effectiveness tot_contrib_below_500 tot_contrib_above_500 woman_d democ_party_d 
			if senate_d ==0, cluster(candidate_id); /* column [1] */


reg leg_effectiveness tot_contrib_below_1000 tot_contrib_above_1000 woman_d democ_party_d 
			if senate_d ==0, cluster(candidate_id); /* column [2] */



reg leg_effectiveness tot_contrib_below_1500 tot_contrib_above_1500 woman_d democ_party_d  
			if senate_d ==0, cluster(candidate_id); /* column [3] */



reg leg_effectiveness tot_contrib_below_2000 tot_contrib_above_2000 woman_d democ_party_d  
			if senate_d ==0, cluster(candidate_id); /* column [4] */



reg leg_effectiveness tot_contrib_below_2500 tot_contrib_above_2500 woman_d democ_party_d  
			if senate_d ==0, cluster(candidate_id); /* column [5] */




/* regressions for the Senate */

reg leg_effectiveness tot_contrib_below_500 tot_contrib_above_500 woman_d democ_party_d  
			if senate_d ==1, cluster(candidate_id); /* column [6] */


reg leg_effectiveness tot_contrib_below_1000 tot_contrib_above_1000 woman_d democ_party_d  
			if senate_d ==1, cluster(candidate_id); /* column [7] */



reg leg_effectiveness tot_contrib_below_1500 tot_contrib_above_1500 woman_d democ_party_d  
			if senate_d ==1, cluster(candidate_id); /* column [8] */



reg leg_effectiveness tot_contrib_below_2000 tot_contrib_above_2000 woman_d democ_party_d  
			if senate_d ==1, cluster(candidate_id); /* column [9] */



reg leg_effectiveness tot_contrib_below_2500 tot_contrib_above_2500 woman_d democ_party_d  
			if senate_d ==1, cluster(candidate_id); /* column [10] */






/******************************************************************************************************************/

/* Table A6: different thresholds between large and small contributions, informed voters */

/* regressions for the House */

reg leg_effectiveness tot_contrib_below_500 tot_contrib_above_500 woman_d democ_party_d black_d age_at_election lawyer_d 
			terms_in_office maj_party_d top_posts_held   
			if senate_d ==0, cluster(candidate_id); /* column [1] */


reg leg_effectiveness tot_contrib_below_1000 tot_contrib_above_1000 woman_d democ_party_d black_d age_at_election lawyer_d 
			terms_in_office maj_party_d top_posts_held   
			if senate_d ==0, cluster(candidate_id); /* column [2] */



reg leg_effectiveness tot_contrib_below_1500 tot_contrib_above_1500 woman_d democ_party_d black_d age_at_election lawyer_d 
			terms_in_office maj_party_d top_posts_held   
			if senate_d ==0, cluster(candidate_id); /* column [3] */



reg leg_effectiveness tot_contrib_below_2000 tot_contrib_above_2000 woman_d democ_party_d black_d age_at_election lawyer_d 
			terms_in_office maj_party_d top_posts_held   
			if senate_d ==0, cluster(candidate_id); /* column [4] */



reg leg_effectiveness tot_contrib_below_2500 tot_contrib_above_2500 woman_d democ_party_d black_d age_at_election lawyer_d 
			terms_in_office maj_party_d top_posts_held   
			if senate_d ==0, cluster(candidate_id); /* column [5] */




/* regressions for the Senate */

reg leg_effectiveness tot_contrib_below_500 tot_contrib_above_500 woman_d democ_party_d black_d age_at_election lawyer_d 
			terms_in_office top_posts_held  
			if senate_d ==1, cluster(candidate_id); /* column [6] */


reg leg_effectiveness tot_contrib_below_1000 tot_contrib_above_1000 woman_d democ_party_d black_d age_at_election lawyer_d 
			terms_in_office top_posts_held   
			if senate_d ==1, cluster(candidate_id); /* column [7] */



reg leg_effectiveness tot_contrib_below_1500 tot_contrib_above_1500 woman_d democ_party_d black_d age_at_election lawyer_d 
			terms_in_office top_posts_held   
			if senate_d ==1, cluster(candidate_id); /* column [8] */



reg leg_effectiveness tot_contrib_below_2000 tot_contrib_above_2000 woman_d democ_party_d black_d age_at_election lawyer_d 
			terms_in_office top_posts_held   
			if senate_d ==1, cluster(candidate_id); /* column [9] */



reg leg_effectiveness tot_contrib_below_2500 tot_contrib_above_2500 woman_d democ_party_d black_d age_at_election lawyer_d 
			terms_in_office top_posts_held   
			if senate_d ==1, cluster(candidate_id); /* column [10] */



/******************************************************************************************************************/



capture log close;
